/* 
	Author: UAB Euro Info
	Url: https://postit.lt
*/
$(function(){
	if(typeof postit_data !== 'object'){
		return;
	}
	if(typeof window.console === 'undefined') {
		window.console = {
			log: function (msg){},
			warn: function (msg){}
		};
	}
	
	var address_xhr;
	var $address = $(postit_data.params.address);
	
	if($address.length !== 1){
		console.warn('postit.lt - Address input not found');
		return;
	}
	if(typeof $address.autocomplete !== 'function'){
		console.warn('postit.lt - Autocomplete is not function');
		return;
	}
	
	if(postit_data.params.is_trial){
		$(postit_data.params.postcode).after(postit_data.params.trial_text);
	}
	
	$address.autocomplete({
		minLength: 4,
		delay: 400,
		source: function(request, response){
			if($(postit_data.params.country).val() !== postit_data.params.country_lt_value){
				return;
			}
			
			if($(element).hasClass('postit-loading')){
				return;
			}
			$(element).addClass('loading postit-loading');
			
			//'is_apartment' and 'apartment' are optional: only for checking if address query has apartment information
			var is_apartment = (/\d+\s*[A-Z]*\s*\-+\s*(\d*|\d+\s*[A-Z]*)$/i.test(request.term));
			var apartment = request.term.match(/\d+\s*[A-Z]*\s*\-+\s*(\d*|\d+\s*[A-Z]*)$/i);
			var element = this.element;
			var request_data = $.extend(postit_data.args, {term: $.trim(request.term)});
			
			if(is_apartment){
				request_data.wide_number = 1;
			}
			
			if(address_xhr){
				address_xhr.abort();
			}
			address_xhr = $.ajax({
				url: postit_data.url,
				dataType: 'json',
				crossDomain: true,
				data: request_data,
				success: function(resp){
					var r = [];
					if ( !resp.success ){
						console.warn(postit_data.url + ' - ' + resp.message);
						response(r);
						return;
					}
					
					for( var i = 0, l = resp.data.length; i < l; i++ ){
						var t = '';
						var address = resp.data[i].address;
						var municipality = resp.data[i].municipality;
						
						if ( address === '' ){
							//Šis atvejis nutinka tada, kai ieškoma ne pagal adresą, o pagal pašto kodą arba vietovę
							if(resp.data[i].mailbox !== ''){
								//Pvz.: ieškant pagal "00002" ar "Pašto dėžutė 1"
								address = ('Post Box ' + resp.data[i].mailbox);
								t = (address + ', ' + resp.data[i].city);
							}
							else {
								//Pvz.: ieškant pagal "20100" ar "Bernotiškių k."
								t = (resp.data[i].city + ', ' + resp.data[i].municipality);
							}
						} else {
							if( is_apartment ){
								address += '-'+apartment[1];
							}
							t = (address + ', ' + resp.data[i].city);
						}

						r.push({
							label: t + ', ' + postit_data.config.prefix + resp.data[i].post_code + postit_data.config.label_suffix,
							value: address,
							address: address,
							municipality: municipality,
							city: resp.data[i].city,
							post_code: resp.data[i].post_code
						});
						response(r);
					}
					
				},
				error: function(){
					response([]);
				},
				complete: function(){
					$(element).removeClass('loading postit-loading');
				}
			});
		},
		select: function(event, ui){
			$(postit_data.params.postcode).val(postit_data.config.prefix + ui.item.post_code);
			$(postit_data.params.city).val(ui.item.city);
			$(postit_data.params.address).val(ui.item.address);
			if(postit_data.params.municipality != ''){
				$(postit_data.params.municipality).val(ui.item.municipality);
			}
		}
	});
});